==> jc-1.4.0.tar.gz: soot/javaToJimple/MethodFinalsChecker.h <==
// public class soot.javaToJimple.MethodFinalsChecker

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class 36e0990db10d250f soot_javaToJimple_MethodFinalsChecker

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_soot_javaToJimple_MethodFinalsChecker_H_
#define _JC_soot_javaToJimple_MethodFinalsChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_ArrayList$object;
struct _jc_java_util_HashMap$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_MethodFinalsChecker$sub_refs	_jc_soot_javaToJimple_MethodFinalsChecker$sub_refs;
typedef struct _jc_soot_javaToJimple_MethodFinalsChecker$sub_nonrefs	_jc_soot_javaToJimple_MethodFinalsChecker$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_MethodFinalsChecker$refs	_jc_soot_javaToJimple_MethodFinalsChecker$refs;
typedef struct _jc_soot_javaToJimple_MethodFinalsChecker$nonrefs	_jc_soot_javaToJimple_MethodFinalsChecker$nonrefs;
typedef struct _jc_soot_javaToJimple_MethodFinalsChecker$object	_jc_soot_javaToJimple_MethodFinalsChecker$object;

typedef const struct _jc_soot_javaToJimple_MethodFinalsChecker$vmethods	_jc_soot_javaToJimple_MethodFinalsChecker$vmethods;
typedef const struct _jc_soot_javaToJimple_MethodFinalsChecker$vtable	_jc_soot_javaToJimple_MethodFinalsChecker$vtable;
typedef const struct _jc_soot_javaToJimple_MethodFinalsChecker$vtype	_jc_soot_javaToJimple_MethodFinalsChecker$vtype;

// Constructors
extern void _jc_soot_javaToJimple_MethodFinalsChecker$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *);

// Virtual methods
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_soot_javaToJimple_MethodFinalsChecker$method$enter$0698e71b16532e07(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *, struct _jc_object *, struct _jc_object *);
extern struct _jc_java_util_ArrayList$object *_jc_soot_javaToJimple_MethodFinalsChecker$method$getClassNames$46be924932b5d809(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *);
extern struct _jc_java_util_ArrayList$object *_jc_soot_javaToJimple_MethodFinalsChecker$method$getLocals$cf778b43bdbd5ea8(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *);
extern struct _jc_java_util_HashMap$object *_jc_soot_javaToJimple_MethodFinalsChecker$method$getNewToOuter$617b2d8b422b158a(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *);
extern void _jc_soot_javaToJimple_MethodFinalsChecker$method$setCurrentSootClass$00257cd85779fc17(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_MethodFinalsChecker$method_info$enter$0698e71b16532e07;
extern _jc_method _jc_soot_javaToJimple_MethodFinalsChecker$method_info$getClassNames$46be924932b5d809;
extern _jc_method _jc_soot_javaToJimple_MethodFinalsChecker$method_info$getLocals$cf778b43bdbd5ea8;
extern _jc_method _jc_soot_javaToJimple_MethodFinalsChecker$method_info$getNewToOuter$617b2d8b422b158a;
extern _jc_method _jc_soot_javaToJimple_MethodFinalsChecker$method_info$setCurrentSootClass$00257cd85779fc17;

// Virtual methods structure
struct _jc_soot_javaToJimple_MethodFinalsChecker$vmethods {
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enter$0698e71b16532e07)(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *, struct _jc_object *, struct _jc_object *);
	struct _jc_java_util_ArrayList$object	*(*getClassNames$46be924932b5d809)(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *);
	struct _jc_java_util_ArrayList$object	*(*getLocals$cf778b43bdbd5ea8)(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *);
	struct _jc_java_util_HashMap$object	*(*getNewToOuter$617b2d8b422b158a)(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *);
	void	(*setCurrentSootClass$00257cd85779fc17)(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_soot_javaToJimple_MethodFinalsChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_soot_javaToJimple_MethodFinalsChecker$vmethods	soot_javaToJimple_MethodFinalsChecker;
};

// Vtype
struct _jc_soot_javaToJimple_MethodFinalsChecker$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_MethodFinalsChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_MethodFinalsChecker$sub_refs {
	struct _jc_java_util_ArrayList$object	*classNames;
	struct _jc_java_util_ArrayList$object	*locals;
	struct _jc_java_util_HashMap$object	*map;
	struct _jc_java_lang_String$object	*currentSootClass;
	struct _jc_java_util_HashMap$object	*newToOuter;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_MethodFinalsChecker$refs {
    _jc_soot_javaToJimple_MethodFinalsChecker$sub_refs	soot_javaToJimple_MethodFinalsChecker;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_MethodFinalsChecker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_MethodFinalsChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_soot_javaToJimple_MethodFinalsChecker$sub_nonrefs	soot_javaToJimple_MethodFinalsChecker;
};

// Object instance structure
struct _jc_soot_javaToJimple_MethodFinalsChecker$object {
	_jc_soot_javaToJimple_MethodFinalsChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_MethodFinalsChecker$vtype	*vtype;
	_jc_soot_javaToJimple_MethodFinalsChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_MethodFinalsChecker$vtype _jc_soot_javaToJimple_MethodFinalsChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_MethodFinalsChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_MethodFinalsChecker$class_object;

#endif	/* _JC_soot_javaToJimple_MethodFinalsChecker_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/MethodFinalsChecker.h <==
// public class soot.javaToJimple.MethodFinalsChecker

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class 36e0990db10d250f soot_javaToJimple_MethodFinalsChecker

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_soot_javaToJimple_MethodFinalsChecker_H_
#define _JC_soot_javaToJimple_MethodFinalsChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_ArrayList$object;
struct _jc_java_util_HashMap$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_MethodFinalsChecker$sub_refs	_jc_soot_javaToJimple_MethodFinalsChecker$sub_refs;
typedef struct _jc_soot_javaToJimple_MethodFinalsChecker$sub_nonrefs	_jc_soot_javaToJimple_MethodFinalsChecker$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_MethodFinalsChecker$refs	_jc_soot_javaToJimple_MethodFinalsChecker$refs;
typedef struct _jc_soot_javaToJimple_MethodFinalsChecker$nonrefs	_jc_soot_javaToJimple_MethodFinalsChecker$nonrefs;
typedef struct _jc_soot_javaToJimple_MethodFinalsChecker$object	_jc_soot_javaToJimple_MethodFinalsChecker$object;

typedef const struct _jc_soot_javaToJimple_MethodFinalsChecker$vmethods	_jc_soot_javaToJimple_MethodFinalsChecker$vmethods;
typedef const struct _jc_soot_javaToJimple_MethodFinalsChecker$vtable	_jc_soot_javaToJimple_MethodFinalsChecker$vtable;
typedef const struct _jc_soot_javaToJimple_MethodFinalsChecker$vtype	_jc_soot_javaToJimple_MethodFinalsChecker$vtype;

// Constructors
extern void _jc_soot_javaToJimple_MethodFinalsChecker$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_soot_javaToJimple_MethodFinalsChecker$method$enter$0698e71b16532e07(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_ArrayList$object *_jc_soot_javaToJimple_MethodFinalsChecker$method$getClassNames$46be924932b5d809(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_ArrayList$object *_jc_soot_javaToJimple_MethodFinalsChecker$method$getLocals$cf778b43bdbd5ea8(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_HashMap$object *_jc_soot_javaToJimple_MethodFinalsChecker$method$getNewToOuter$617b2d8b422b158a(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *) _JC_JCNI_ATTR;
extern void _jc_soot_javaToJimple_MethodFinalsChecker$method$setCurrentSootClass$00257cd85779fc17(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_MethodFinalsChecker$method_info$enter$0698e71b16532e07;
extern _jc_method _jc_soot_javaToJimple_MethodFinalsChecker$method_info$getClassNames$46be924932b5d809;
extern _jc_method _jc_soot_javaToJimple_MethodFinalsChecker$method_info$getLocals$cf778b43bdbd5ea8;
extern _jc_method _jc_soot_javaToJimple_MethodFinalsChecker$method_info$getNewToOuter$617b2d8b422b158a;
extern _jc_method _jc_soot_javaToJimple_MethodFinalsChecker$method_info$setCurrentSootClass$00257cd85779fc17;

// Virtual methods structure
struct _jc_soot_javaToJimple_MethodFinalsChecker$vmethods {
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enter$0698e71b16532e07)(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_util_ArrayList$object	*(*getClassNames$46be924932b5d809)(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_ArrayList$object	*(*getLocals$cf778b43bdbd5ea8)(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_HashMap$object	*(*getNewToOuter$617b2d8b422b158a)(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *) _JC_JCNI_ATTR;
	void	(*setCurrentSootClass$00257cd85779fc17)(_jc_env *, struct _jc_soot_javaToJimple_MethodFinalsChecker$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_MethodFinalsChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_soot_javaToJimple_MethodFinalsChecker$vmethods	soot_javaToJimple_MethodFinalsChecker;
};

// Vtype
struct _jc_soot_javaToJimple_MethodFinalsChecker$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_MethodFinalsChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_MethodFinalsChecker$sub_refs {
	struct _jc_java_util_ArrayList$object	*classNames;
	struct _jc_java_util_ArrayList$object	*locals;
	struct _jc_java_util_HashMap$object	*map;
	struct _jc_java_lang_String$object	*currentSootClass;
	struct _jc_java_util_HashMap$object	*newToOuter;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_MethodFinalsChecker$refs {
    _jc_soot_javaToJimple_MethodFinalsChecker$sub_refs	soot_javaToJimple_MethodFinalsChecker;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_MethodFinalsChecker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_MethodFinalsChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_soot_javaToJimple_MethodFinalsChecker$sub_nonrefs	soot_javaToJimple_MethodFinalsChecker;
};

// Object instance structure
struct _jc_soot_javaToJimple_MethodFinalsChecker$object {
	_jc_soot_javaToJimple_MethodFinalsChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_MethodFinalsChecker$vtype	*vtype;
	_jc_soot_javaToJimple_MethodFinalsChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_MethodFinalsChecker$vtype _jc_soot_javaToJimple_MethodFinalsChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_MethodFinalsChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_MethodFinalsChecker$class_object;

#endif	/* _JC_soot_javaToJimple_MethodFinalsChecker_H_ */
